Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ImageAnnotatorService ¶
type ImageAnnotatorService struct{}
ImageAnnotatorService renders bounding boxes, product labels, and compliance status indicators on images.
func NewImageAnnotatorService ¶
func NewImageAnnotatorService() *ImageAnnotatorService
NewImageAnnotatorService constructs a new ImageAnnotatorService.
func (*ImageAnnotatorService) Annotate ¶
func (s *ImageAnnotatorService) Annotate( imageBytes []byte, detections []dto.CustomLabelDetection, matchStatuses map[int]enums.MatchStatus, ) ([]byte, error)
Annotate draws bounding boxes and status labels over the provided image bytes.
Click to show internal directories.
Click to hide internal directories.